JsDoc Reference - Index

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:50 GMT-0000 (GMT)
HTML template: Codeview

# Class Index

- ## _global_

- ## AutoFill

  AutoFill

- ## AutoFill#dom

  Common and useful DOM elements for the class instance

- ## AutoFill#s

  Settings object which contains customisable information for AutoFill instance

- ## AutoFill#s.border

  Cached information about the border display

- ## AutoFill#s.columns

  Information stored for each column.

- ## AutoFill#s.drag

  Store for live information for the current drag

- ## AutoFill#s.filler

  Cached information about the little dragging icon (the filler)

- ## AutoFill#s.screen

  Data cache for information that we need for scrolling the screen when we near the edges

- ## AutoFill#s.scroller

  Data cache for the position of the DataTables scrolling element (when scrolling is enabled)